[![Documentation status](https://readthedocs.org/projects/pottok/badge/?version=latest)](https://pottok.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/pottok.svg)](https://badge.fury.io/py/pottok)
[![Build status](https://api.travis-ci.com/obernardoff/pottok.svg?branch=master)](https://travis-ci.com/obernardoff/pottok)
[![Downloads](https://pepy.tech/badge/pottok)](https://pepy.tech/project/pottok)

# Pottok - Python Optimal Transport for Terrestrial Observation Knowledge

Pottok is a python library based on POT Python Optimal Transport. It provides a grid search for POT with two different method : crossed and circular.

# Classes description

The two avalable classes are :
 - pottok.OptimalTransportGridsearch : Create a gris dearch compatible with POT. The user can use the circular grid search based on the circular validation and crossed grid search based on crossed validation. This one can use scikit learn or museotoolbox GridSearchCV.
 - pottok.RasterOptimalTransport : this class is specifically for raster use. 

# How it works ? 

Since a picture is worth more than a thousand words, we will use a concrete example to illustrate these two grid search
>Add tetris draw

# Pottok installation
